; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |----------------------------------------------------------
; Please define Anim 74140108 in your AIR file if AND ONLY IF you place these
; 7 Hold Button commands immediately after the 11 Single Button and Hold Dir
; commands at the very top of your CMD list, as demonstrated here.
; In this version of the AI code, these commands are only used by the XOR
; method, and thus are optional.  But there remains a possibility that a
; future version of the helper method might be helped by having these
; commands placed here, and Anim 74140108 would then be used to indicate
; that a partner character has a compatible CMD.

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

;--- None of your own command definitions should be above this line. ---

;-| CPU |--------------------------------------------------------------
; Note that if you make any changes to the basic one-button or recovery
; commands, you'll need to make the same changes to their matching commands here
; and/or in the XOR VarSet controller.  That includes things like, for example:
;  * changing the recovery command to use a different combination of buttons.
;  * renaming the b button command as "d", or the start button command as "s".
;  * switching the button names around, e.g. so button y triggers "a" and button a triggers "y".
;  * having more than one way to trigger the same command name.
; If you understand how the XOR method works, the proper changes should be obvious.
; If you don't understand it, then simply disable the lines in the XOR VarSet
; controller that correspond to the commands you've altered.

[Command]
name = "a2"
command = a
time = 1

[Command]
name = "b2"
command = b
time = 1

[Command]
name = "c2"
command = c
time = 1

[Command]
name = "x2"
command = x
time = 1

[Command]
name = "y2"
command = y
time = 1

[Command]
name = "z2"
command = z
time = 1

[Command]
name = "start2"
command = s
time = 1

[Command]
name = "holdfwd2"
command = /$F
time = 1

[Command]
name = "holdback2"
command = /$B
time = 1

[Command]
name = "holdup2"
command = /$U
time = 1

[Command]
name = "holddown2"
command = /$D
time = 1

[Command]
name = "holda2"
command = /a
time = 1

[Command]
name = "holdb2"
command = /b
time = 1

[Command]
name = "holdc2"
command = /c
time = 1

[Command]
name = "holdx2"
command = /x
time = 1

[Command]
name = "holdy2"
command = /y
time = 1

[Command]
name = "holdz2"
command = /z
time = 1

[Command]
name = "holdstart2"
command = /s
time = 1

[Command]
name = "recovery2"
command = x+y
time = 1

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "QCF_2P"
command = ~D, DF, F, x+y

[Command]
name = "QCF_2P"
command = ~D, DF, F, y+z

[Command]
name = "QCF_2P"
command = ~D, DF, F, x+z

[Command]
name = "QCB_2P"
command = ~D, DB, B, x+y

[Command]
name = "QCB_2P"
command = ~D, DB, B, y+z

[Command]
name = "QCB_2P"
command = ~D, DB, B, x+z

[Command]
name = "QCF_2P"
command = ~D, F, x+y

[Command]
name = "QCF_2P"
command = ~D, F, y+z

[Command]
name = "QCF_2P"
command = ~D, F, x+z

[Command]
name = "QCB_2P"
command = ~D, B, x+y

[Command]
name = "QCB_2P"
command = ~D, B, y+z

[Command]
name = "QCB_2P"
command = ~D, B, x+z

[Command]
name = "HCB_2P"
command = ~F, D, B, x+y

[Command]
name = "HCB_2P"
command = ~F, D, B, y+z

[Command]
name = "HCB_2P"
command = ~F, DF, D, DB, B, x+z

[Command]
name = "HCB_2P"
command = ~F, DF, D, DB, B, x+y

[Command]
name = "HCB_2P"
command = ~F, DF, D, DB, B, y+z

[Command]
name = "HCB_2P"
command = ~F, D, B, x+z

[Command]
name = "FatalKO"
command = ~D, D, D, D, D, x+y
time = 40

[Command]
name = "FatalKO"
command = ~D, D, D, D, D, y+z
time = 40

[Command]
name = "FatalKO"
command = ~D, D, D, D, D, x+z
time = 40

[Command]
name = "FatalKO"
command = ~D, D, D, D, D, b
time = 40

[Command]
name = "ArcBlaze"
command = ~D, F, x+y+z

[Command]
name = "ArcBlaze"
command = ~D, DF, F, x+y+z

[Command]
name = "r_ArcBlaze"
command = ~D, B, x+y+z

[Command]
name = "r_ArcBlaze"
command = ~D, DB, B, x+y+z

[Command]
name = "CriticalHeart"
command = ~D, D, D, x+y+z
time = 20

[Command]
name = "CriticalHeart"
command = ~D, D, D, b
time = 20

[Command]
name = "QCFx2_Arc"
command = ~D, DF, F, D, DF, F, c

[Command]
name = "QCBx2_Arc"
command = ~D, DB, B, D, DB, B, c

[Command]
name = "FHCF_Arc"
command = ~F, B, DB, D, DF, F, c

[Command]
name = "FHCF_Arc"
command = ~F, B, D, F, c

[Command]
name = "FHCF_Arc"
command = ~F, $B, D, $F, c

[Command]
name = "BHCB_Arc"
command = ~B, F, DF, D, DB, B, c

[Command]
name = "BHCB_Arc"
command = ~B, F, D, B, c

[Command]
name = "BHCB_Arc"
command = ~B, $F, D, $B, c


;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_z"
command = ~F, D, DF, z

[Command]
name = "r_upper_x"
command = ~B, D, DB, x

[Command]
name = "r_upper_y"
command = ~B, D, DB, y

[Command]
name = "r_upper_z"
command = ~B, D, DB, z

[Command]
name = "charge_x"
command = ~15$B, F, x
time = 10

[Command]
name = "charge_y"
command = ~15$B, F, y
time = 10

[Command]
name = "charge_z"
command = ~15$B, F, z
time = 10

[Command]
name = "HCB_x"
command = ~F, D, B, x
[Command]
name = "HCB_x"
command = ~F, DF, D, DB, B, x

[Command]
name = "HCB_y"
command = ~F, D, B, y
[Command]
name = "HCB_y"
command = ~F, DF, D, DB, B, y

[Command]
name = "HCB_z"
command = ~F, D, B, z
[Command]
name = "HCB_z"
command = ~F, DF, D, DB, B, z

[Command]
name = "HCF_x"
command = ~B, D, F, x
[Command]
name = "HCF_x"
command = ~B, DB, D, DF, F, x

[Command]
name = "HCF_y"
command = ~B, D, F, y
[Command]
name = "HCF_y"
command = ~B, DB, D, DF, F, y

[Command]
name = "HCF_z"
command = ~B, D, F, z
[Command]
name = "HCF_z"
command = ~B, DB, D, DF, F, z

[Command]
name = "imdrawin"
command = ~D, D, x

[Command]
name = "imdrawin"
command = ~D, D, y

[Command]
name = "imdrawin"
command = ~D, D, z

[Command]
name = "QCF_Arc"
command = ~D, DF, F, c

[Command]
name = "QCB_Arc"
command = ~D, DB, B, c

[Command]
name = "DP_Arc"
command = ~F, D, DF, c

[Command]
name = "RDP_Arc"
command = ~B, D, DB, c

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "AFF"     ;Required (do not remove)
command = $F, ~F, F
time = 10

[Command]
name = "ABB"     ;Required (do not remove)
command = $B, ~B, B
time = 10

[Command]
name = "SupahJump"
;command = ~$D, $U
command = ~$D, $U
time = 5
buffer.time = 2

[Command]
name = "ChargedSupahJump"
;command = ~$D, $U
command = ~12$D, $U
time = 5
buffer.time = 2

[Command]
name = "upper_what"
command = ~15$D, $U, x
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, y
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, z
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, a
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, b
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, c
time = 10


;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = x
time = 1

[Command]
name = "recovery"
command = y
time = 1

[Command]
name = "recovery"
command = z
time = 1

[Command]
name = "Extendo"
command = x+y+z
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

; The main purpose of having these next two controllers here at the top of
; StateDef -1 is to make sure the AI helper never changes to a different state,
; nor encounters any VarSets within State -1.
; But they also improve efficiency by preventing Mugen from wasting time
; processing the entire State -1 for the helper.
[State -1, AI Helper Check]
type = ChangeState
trigger1 = IsHelper(9741)
value = 9741

[State -1, AI Helper Check 2]
type = ChangeState
trigger1 = IsHelper(9742)
value = 9742

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(9) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact
trigger2 = stateno != 420
trigger2 = stateno != 250
trigger3 = stateno = [210,212]
trigger3 = animelemtime(5) >= 0
trigger4 = (stateno = 743 && time >= 7) || (stateno = 744 && time >= 16) || (stateno = 746 && time >= 9)
var(9) = 1

[State -1, AI Reset]
type = VarSet
trigger1 = 1
var(52) = 0

; AI-related stuff starts here

[State AI, Consider S.X]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (10*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 123)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),41-(7*movecontact)]
triggerall = p2dist y >= -40 - (enemynear,vel y*7)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 7  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100 || (stateno = [743,746])
trigger2 = stateno = 400
trigger2 = movecontact
var(52) = 200
ignorehitpause = 1
[State AI, Consider S.Y]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (9*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 40)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),140-(5*movecontact)]
triggerall = p2dist y >= -50 - (enemynear,vel y*5)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -55
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100 || (stateno = [743,746])
trigger2 = stateno = 200 || stateno = 400
trigger2 = movecontact
var(52) = ifelse(p2bodydist x<=99&&random<900,210,212)
ignorehitpause = 1
[State AI, Consider S.Z]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (10*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 40)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),42-(5*movecontact)]
triggerall = p2dist y >= -90 - (enemynear,vel y*5)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -9
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 5 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100 || (stateno = [743,746])
trigger2 = stateno = 200 || stateno = 400
trigger2 = movecontact
var(52) = 220
ignorehitpause = 1
[State AI, Consider S.C]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (7*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 40)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),130-(14*movecontact)]
triggerall = p2dist y >= -38 - (enemynear,vel y*14)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -38
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 14 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100 || (stateno = [743,746])
trigger2 = stateno = 200 || stateno = 400
trigger2 = movecontact
var(52) = 250
ignorehitpause = 1

[State AI, Consider C.X]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (10*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 220)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),37-(4*movecontact)]
triggerall = p2dist y >= -29 - (enemynear,vel y*4)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 4 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100 || (stateno = [743,746])
trigger2 = stateno = 400
trigger2 = movecontact
var(52) = 400
ignorehitpause = 1
[State AI, Consider C.Y]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (9*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 40)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),100-(8*movecontact)]
triggerall = p2dist y >= -53 - (enemynear,vel y*8)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 8  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100 || (stateno = [743,746])
trigger2 = stateno = 400 || stateno = 200
trigger2 = movecontact
var(52) = 410
ignorehitpause = 1
[State AI, Consider C.Z]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (8*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 40)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),140-(14*movecontact)]
triggerall = p2dist y >= -20 - (enemynear,vel y*14)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 14  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100 || (stateno = [743,746])
trigger2 = stateno = 400 || stateno = 200
trigger2 = movecontact
var(52) = 420
ignorehitpause = 1
[State AI, Consider C.C]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (7*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 40)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),68-(15*movecontact)]
triggerall = p2dist y >= -50 - (enemynear,vel y*15)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -14
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 15 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100 || (stateno = [743,746])
trigger2 = stateno = 400 || stateno = 200 || stateno = 220
trigger2 = movecontact
var(52) = 450
ignorehitpause = 1

[State AI, Consider holding]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
trigger1 = stateno = 250
trigger1 = p2statetype != A || p2statetype = L
trigger1 = (enemynear, ctrl = 1) || (p2statetype=L) || (p2stateno=[120,169]) || (p2stateno = [5100,5120])
trigger2 = stateno = 250
trigger2 = p2statetype = A
trigger2 = p2bodydist x != [ifelse(p2statetype!=A,-5,0),130-(14*movecontact)]
trigger2 = p2dist y < -20 - (enemynear,vel y*8)
trigger3 = stateno = 450
trigger3 = p2statetype != A || p2statetype = L
trigger3 = (enemynear, ctrl = 1) || (p2statetype=L) || (p2stateno=[120,169]) || (p2stateno = [5100,5120])
trigger4 = stateno = 450
trigger4 = p2statetype = A
trigger4 = p2bodydist x != [ifelse(p2statetype!=A,-5,0),68-(15*movecontact)]
trigger4 = p2dist y < -42 - (enemynear,vel y*8)
var(52) = 251
ignorehitpause = 1

[State AI, J.X]
type = Varset
triggerall = numenemy
triggerall = var(52) = 0 || random < 123
triggerall = var(55)
triggerall = p2bodydist x = [-18+(vel x*6)+(enemynear,vel x*6),43+(vel x*6)+(enemynear,vel x*6)]
triggerall = P2dist y = [-77+(vel y*6)+(enemynear,vel y*6),40+(vel y*6)+(enemynear,vel y*6)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5190]
triggerall = p2Statetype = A || vel y >= 0 || p2movetype = A
triggerall = (stateno != [120,169])
triggerall = random < (5*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl || stateno = 110 || stateno = 741
var(52) = 600
[State AI, J.Y]
type = Varset
triggerall = numenemy
triggerall = var(52) = 0 || random < 123
triggerall = var(55)
triggerall = p2bodydist x = [-48,15]
triggerall = P2dist y = [-47,ifelse(p2statetype=A,100,60)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5190]
triggerall = p2Statetype = A || vel y >= 0 || p2movetype = A
triggerall = (stateno != [120,169])
triggerall = random < (5*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl || stateno = 110 || stateno = 741
trigger2 = (stateno = 600 && animelemtime(6)>=0) || (stateno = 650 && animelemtime(8)>=0)
trigger2 = movecontact
var(52) = 610
[State AI, J.Z]
type = Varset
triggerall = numenemy
triggerall = var(52) = 0 || random < 123
triggerall = var(55)
triggerall = p2bodydist x = [0,115]
triggerall = P2dist y = [-57,80]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5190]
triggerall = p2Statetype = A || vel y >= 0 || p2movetype = A
triggerall = (stateno != [120,169])
triggerall = random < (5*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl || stateno = 110 || stateno = 741
trigger2 = (stateno = 600 && animelemtime(6)>=0) || stateno = 610 || (stateno = 650 && animelemtime(8)>=0)
trigger2 = movecontact
var(52) = 620
[State AI, J.C]
type = Varset
triggerall = numenemy
triggerall = var(52) = 0 || random < 123
triggerall = var(55)
triggerall = p2bodydist x = [-70+(vel x*7)+(enemynear,vel x*7),49+(vel x*7)+(enemynear,vel x*7)]
triggerall = P2dist y = [-64+(vel y*7)+(enemynear,vel y*7),128+(vel y*7)+(enemynear,vel y*7)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5190]
triggerall = p2Statetype = A || vel y >= 0 || p2movetype = A
triggerall = (stateno != [120,169])
triggerall = random < (5*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl || stateno = 110 || stateno = 741
trigger2 = (stateno = 600 && animelemtime(6)>=0)
trigger2 = movecontact
var(52) = 650

[State AI, Carrying]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (2*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 50)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),ifelse(movehit,75,200)-(10*(movecontact>=1))]
triggerall = p2dist y >= -30 - (enemynear,vel y*10)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 10  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
trigger1 = !moveguarded
var(52) = 1000
ignorehitpause = 1
[State AI, Carrying]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (2*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 50)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),ifelse(movehit,75,240)-(14*(movecontact>=1))]
triggerall = p2dist y >= -30 - (enemynear,vel y*14)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 14  ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
trigger1 = !moveguarded
var(52) = 1010
ignorehitpause = 1
[State AI, Breaking The Guard]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (2*(var(55)*var(55))) * ifelse(moveguarded,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 50)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),230-(25*(movecontact>=1))]
triggerall = p2dist y >= -30 - (enemynear,vel y*25)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 25 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
;trigger1 = !moveguarded
var(52) = 1020
ignorehitpause = 1

[State AI, Buying a Prince album]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (3*(var(55)*var(55))) * ifelse(movehit,2,1) * ifelse(stateno=52||prevstateno=52,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 450)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),ifelse(movehit,49,75)-(8*(movecontact>=1))]
triggerall = p2dist y >= -160 - (enemynear,vel y*8)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= ifelse(movehit,-78,-40)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 8 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
trigger1 = !moveguarded || (moveguarded&&p2statetype=C)
var(52) = 1050
ignorehitpause = 1
[State AI, Buying a Prince album]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (3*(var(55)*var(55))) * ifelse(movehit,2,1) * ifelse(stateno=52||prevstateno=52,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 100)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),ifelse(movehit,49,115)-(8*(movecontact>=1))]
triggerall = p2dist y >= -180 - (enemynear,vel y*8)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= ifelse(movehit,-78,-40)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 8 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
trigger1 = !moveguarded || (moveguarded&&p2statetype=C)
var(52) = 1060
ignorehitpause = 1
[State AI, Buying a Prince album]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (3*(var(55)*var(55))) * ifelse(movehit,2,1) * ifelse(stateno=52||prevstateno=52,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 450)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),45-(7*(movecontact>=1))]
triggerall = p2dist y >= -140 - (enemynear,vel y*7)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -17
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 7 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
trigger1 = !moveguarded
var(52) = 1070
ignorehitpause = 1
[State AI, Buying a Prince album Midair]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (3*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 450)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),50]
triggerall = p2dist y = [-100 - (enemynear,vel y*6),47]
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -78
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 6 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 610 || stateno = 620 || stateno = 650
trigger2 = (stateno != 600 || animelemtime(6)>=0)
trigger2 = (stateno != 620 || animelemtime(7)>=0)
trigger2 = (stateno != 650 || animelemtime(8)>=0)
trigger2 = movehit
var(52) = 1052
ignorehitpause = 1

[State AI, Consider Gifting Medal of Honor:Warfighter]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (3*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 100)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),100-(12*(movecontact>=1))+(enemynear,vel x*12)]
triggerall = p2dist y >= -38 - (enemynear,vel y*25)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -38
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 19 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
trigger1 = !moveguarded
var(52) = 1150
ignorehitpause = 1
[State AI, Consider Gifting Medal of Honor:Warfighter]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (3*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 100)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),53-(12*(movecontact>=1))+(enemynear,vel x*12)]
triggerall = p2dist y >= -180-(p2bodydist x*2) - (enemynear,vel y*25)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -70-(p2bodydist x/2)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 19 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
trigger1 = !moveguarded
var(52) = 1160
ignorehitpause = 1
[State AI, Consider Gifting Medal of Honor:Warfighter]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (2*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 100)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,-15),25+(enemynear,vel x*12)]
triggerall = p2dist y >= -230 - (enemynear,vel y*25)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -75-(p2bodydist x*2)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 19 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025]) || (p2stateno = [120,169])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
trigger1 = !moveguarded
var(52) = 1170
ignorehitpause = 1

[State AI, Drawing Zoning]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (2*(var(55)*var(55)))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2bodydist x >= 100 || (p2stateno = [5000,5190])
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -55
triggerall = statetype != A || numhelper(2010)=0
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
trigger1 = !movehit
var(52) = ifelse(numhelper(2010)=0&&(random<500||statetype=A),1500+random%2,1100)
ignorehitpause = 1

[State AI, Consider running over Mickey Mouse]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || (random < 100+var(55) && (var(52)!=[200,640]))
triggerall = var(55)
triggerall = random < (7*(var(55)*var(55)))
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0 && enemynear, animtime <= -8)
triggerall = p2stateno != [5080,5190]
triggerall = (p2bodydist x = [-9,70]) || (!movehit)
triggerall = p2bodydist y + (enemynear,vel y*8) = [-30,20]
triggerall = power >= 1000
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A)
triggerall = statetype != A
triggerall = (p2stateno != [120,165])
triggerall = (prevstateno != [3000,3902]) || (stateno = [3000,3902])
triggerall = time >= 7-var(55) || random < 10
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*8) + (enemynear, pos y) <= -8 ) || (p2stateno != [5030,5070])
triggerall = (p2movetype != H) || (enemynear,gethitvar(hittime) >= 8) || (p2statetype=A)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
var(52) = 3000
ignorehitpause = 1
[State AI, Consider Buying out George Lucas's Studio]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || (random < 100+var(55) && (var(52)!=[200,640]))
triggerall = var(55)
triggerall = random < (9*(var(55)*var(55)))
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0 && enemynear, animtime <= -6)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [-45,40]
triggerall = p2bodydist y + (enemynear,vel y*4) = [-200,20]
triggerall = power >= 1000
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A)
triggerall = statetype != A
triggerall = (p2stateno != [120,165])
triggerall = (prevstateno != [3000,3902]) || (stateno = [3000,3902])
triggerall = time >= 7-var(55) || random < 10
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*6) + (enemynear, pos y) <= -5 ) || (p2stateno != [5030,5070])
triggerall = (p2movetype != H) || (enemynear,gethitvar(hittime) >= 5) || (p2statetype=A)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
trigger2 = stateno = [1000,1020]
trigger2 = movecontact >= 8
trigger3 = stateno = 1020 && moveguarded
var(52) = 3050
ignorehitpause = 1
[State AI, Consider ripping off Strawbelly Jam]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || (random < 100+var(55) && (var(52)!=[200,640]))
triggerall = var(55)
triggerall = random < (6*(var(55)*var(55)))
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0 && enemynear, animtime <= -6)
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [-48+p2bodydist y,48+p2bodydist y]
triggerall = p2bodydist y >= -30
triggerall = power >= 1000
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A)
triggerall = (p2stateno != [120,165])
triggerall = (prevstateno != [3000,3902]) || (stateno = [3000,3902])
triggerall = time >= 7-var(55) || random < 10
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*19) + (enemynear, pos y) <= -19 ) || (p2stateno != [5030,5070])
triggerall = (p2movetype != H) || (enemynear,gethitvar(hittime) >= 19) || (p2statetype=A)
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 610 || stateno = 620 || stateno = 650
trigger2 = (stateno != 600 || animelemtime(6)>=0)
trigger2 = (stateno != 620 || animelemtime(7)>=0)
trigger2 = (stateno != 650 || animelemtime(8)>=0)
trigger2 = movehit
var(52) = 3100
ignorehitpause = 1
[State AI, Consider picking the Demoman Classn]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || (random < 100+var(55) && (var(52)!=[200,640]))
triggerall = var(55)
triggerall = random < (1*(var(55)*var(55)))
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0 && enemynear, animtime <= -8)
triggerall = power >= 1000
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A)
;triggerall = statetype != A
triggerall = (p2stateno != [120,165]) || (random < 90)
triggerall = (prevstateno != [3000,3902]) || (stateno = [3000,3902])
triggerall = time >= 7-var(55) || random < 10
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*8) + (enemynear, pos y) <= -8 ) || (p2stateno != [5030,5070])
triggerall = (p2movetype != H) || (enemynear,gethitvar(hittime) >= 8) || (p2statetype=A)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
trigger2 = statetype = A
trigger2 = ctrl || (stateno = [600,650])
trigger2 = (stateno != 600 || animelemtime(6)>=0)
trigger2 = (stateno != 620 || animelemtime(7)>=0)
trigger2 = (stateno != 650 || animelemtime(8)>=0)
var(52) = 1600
ignorehitpause = 1
[State AI, Consider wasting a superbar like an idiot]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || (random < 100+var(55) && (var(52)!=[200,640]))
triggerall = var(55)
triggerall = random < (1*(var(55)*var(55)))
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0 && enemynear, animtime <= -8)
triggerall = power >= 1000
triggerall = !numhelper(1610)
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A)
triggerall = statetype != A
triggerall = (p2stateno != [120,165]) || (random < 90)
triggerall = (prevstateno != [3000,3902]) || (stateno = [3000,3902])
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = !movehit
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
var(52) = 1610
ignorehitpause = 1

[State AI, Consider betting on a nigh forgotten 90s videogame character]
type = VarSet
triggerall = numenemy
;triggerall = var(52) = 0 || (random < 100+var(55) && (var(52)!=[200,640]))
triggerall = var(55)
triggerall = random < (3*(var(55)*var(55))) + (300-ceil(fvar(20)))
triggerall = random < 300 + ((lifemax - life)/16)
;triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0 && enemynear, animtime <= -8)
triggerall = p2bodydist x = [-5,154]
triggerall = fvar(20) > 0
triggerall = fvar(20) < 120
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A)
triggerall = statetype != A
triggerall = (p2stateno != [120,165]) || (random < 123)
triggerall = (prevstateno != [3000,3902]) || (stateno = [3000,3902])
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
var(52) = 3250
ignorehitpause = 1


[State AI, Consider growing in stature]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || (random < 100+var(55) && (var(52)!=[200,640]))
triggerall = var(55)
triggerall = random < (6*(var(55)*var(55)))
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = (p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing)
triggerall = ((p2stateno = [5070,5190]) && backedgebodydist >= 48) || (p2bodydist x >= 100)
triggerall = power >= 3000
triggerall = life <= ceil(lifemax*0.3333)
triggerall = (p2movetype = H) || (enemynear, ctrl = 0) || (p2stateno = [5070,5190])
triggerall = statetype != A
triggerall = (prevstateno != [3000,3902]) || (stateno = [3000,3902])
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
trigger1 = !movehit
var(52) = 3200
ignorehitpause = 1


[State AI, Consider challenging the opponent to Survival Arts]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || (random < 100+var(55) && (var(52)!=[200,640]))
triggerall = var(55)
triggerall = random < (9*(var(55)*var(55)))
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0 && enemynear, animtime <= -8) || (random < 100)
triggerall = p2stateno != [5070,5190]
triggerall = enemynear,prevstateno != 5120
triggerall = (p2bodydist x = [-9,20])
triggerall = p2statetype != A
triggerall = p2statetype != L
triggerall = power >= 3000
triggerall = p2life <= ceil(enemynear,lifemax*0.3333)
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A)
triggerall = statetype != A
triggerall = (p2stateno != [120,165])
triggerall = (prevstateno != [3000,3902]) || (stateno = [3000,3902])
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
var(52) = 3400
ignorehitpause = 1

[State AI, Consider Throwing]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 900
triggerall = var(55)
triggerall = random < (15*(var(55)*var(55)))
triggerall = p2stateno != [5080,5190]
triggerall = abs(p2bodydist x) < 6
triggerall = statetype != A
triggerall = p2movetype != H
triggerall = p2statetype != A
triggerall = prevstateno != [800,830]
triggerall = var(8) = 0
trigger1 = stateno != 40
trigger1 = ctrl
var(52) = 800
ignorehitpause = 1
[State AI, AI(R) Throw]
type = Varset
triggerall = var(55)
triggerall = statetype = A
triggerall = ctrl
triggerall = random < (15*(var(55)*var(55)))
triggerall = prevstateno != 45
trigger1 = p2bodydist X < 14
trigger1 = abs(p2bodydist y) < 40
trigger1 = (p2statetype = A)
trigger1 = p2movetype != H
var(52) = 850


[State AI, Consider Advancing]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = random < (33*var(55))
triggerall = ((enemynear, ctrl = 0) && p2movetype != A) || (p2movetype = A && (enemynear, facing = facing))
triggerall = (p2stateno != [5080,5190]) || (p2bodydist x = [45,100])
triggerall = p2bodydist x >= 45
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 100
trigger1 = ctrl
trigger1 = !moveguarded
var(52) = ifelse(random<200,41,ifelse(random<500&&fvar(14)>=60,743,100))
[State AI, Consider Advancing mid-air]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = random < (33*var(55))
triggerall = ((enemynear, ctrl = 0) && p2movetype != A) || (p2movetype = A && (enemynear, facing = facing))
triggerall = (p2stateno != [5080,5190])
triggerall = p2bodydist x >= 80
triggerall = p2bodydist y <= 100
triggerall = statetype = A
triggerall = time >= 7-var(55) || random < 10
triggerall = !(var(27) & floor(exp(1*ln(2)) + 0.5) )
trigger1 = ctrl
trigger1 = pos y <= -35 || vel y >= 0
var(52) = ifelse(random<500&&fvar(14)>=60,742,110)
[State AI, Consider jumping in]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55) + (100*(stateno = 640)) + (100*(stateno = 240))
triggerall = var(55)
triggerall = p2stateno != [5080,5190]
triggerall = statetype != A || stateno = 640
triggerall = p2statetype = A && p2movetype = H
triggerall = (enemynear, pos y <= -45)
trigger1 = ctrl || stateno = 100 || stateno = 40
trigger2 = (stateno = 220 && animelemtime(6)>=0) || (stateno = 450)
trigger2 = movecontact
var(52) = ifelse(random<123&&fvar(14)>=60,740,ifelse(p2bodydist x>=20,ifelse(p2bodydist x>=160,44,41),42))
ignorehitpause = 1

[State AI, Consider pulling off more mean combos]
type = VarSet
triggerall = numenemy
triggerall = var(55)
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = random < (2*(var(55)*var(55)))
triggerall = fvar(14) >= 60
triggerall = movecontact
triggerall = !enemynear,movereversed
triggerall = power >= ifelse(stateno>=3000,1000,2000)
trigger1 = stateno = 3000 && (time >= 100)
trigger2 = stateno = 1070 && (time >= 30)
trigger3 = stateno = [1050,1060]
trigger4 = stateno = 250 || stateno = 860
trigger5 = stateno = [1150,1170]
trigger5 = numtarget
trigger5 = target,statetype=A
var(52) = ifelse(statetype=A,742,ifelse(moveguarded,744,ifelse(p2statetype=A,740,743)))
[State AI, KEEP RUNNING]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 40) || (stateno = 746)
triggerall = p2bodydist x <= 40
trigger1 = stateno = [743,747]
var(52) = 741
ignorehitpause = 1

[State AI, Consider EXTENDING]
type = VarSet
triggerall = numenemy
triggerall = var(55)
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = random < (1*(var(55)*var(55))) + ((lifemax-life)/10) + ((lifemax-p2life)/10)
triggerall = fvar(20) = 0
triggerall = !enemynear,movereversed
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (movehit)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = var(9)
trigger1 = (stateno != 220 || animelemtime(5)>=0)
trigger1 = (stateno != 410 || animelemtime(9)>=0)
trigger1 = (stateno != 420 || animelemtime(12)>=0)
trigger2 = stateno = [1000,1999]
var(52) = 700

[State AI, SLAM]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (10*(var(55)*var(55)))
triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x = [-5,79-(enemynear,vel x*21*facing*(enemynear,facing))]
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno = 3201
var(52) = ifelse(numtarget(3201),3202,3201+random%3)
ignorehitpause = 1
[State AI, STOMP]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (5*(var(55)*var(55)))
;triggerall = p2stateno != [5080,5190]
triggerall = p2bodydist x > 79
triggerall = p2dist y >= -29 - (enemynear,vel y*7)
triggerall = time >= 7-var(55) || random < 10
triggerall = prevstateno != 3204 || random < 50
trigger1 = stateno = 3201
var(52) = 3204
ignorehitpause = 1

[State AI, Guard S]
type = ChangeState
triggerall = stateno != 40
triggerall = random < 125*var(55)
triggerall = (var(55)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
trigger1 = (P2StateType != C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = ifelse(random<64&&(stateno!=[120,159])&&fvar(14)>=60,744,130)

[State AI, Guard L]
type = ChangeState
triggerall = stateno != 40
triggerall = random < 125*var(55)
triggerall = (var(55)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
trigger1 = (P2StateType = C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = ifelse(random<64&&(stateno!=[120,159])&&fvar(14)>=60,744,131)


; AI-related stuff ends here

;===========================================================================
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;Triple Kung Fu Palm (uses one super bar)
;OJt[˂iQ[WxPj
[State -1, Arcana Blaze]
type = ChangeState
value = 3250
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "ArcBlaze",command = "r_ArcBlaze")) || var(52) = 3250
triggerall = fvar(20) >= 1
triggerall = statetype != A
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1020])
trigger2 = movecontact
trigger3 = stateno = 3000
trigger3 = time >= 60


[State -1, Destination Disneyland]
type = ChangeState
value = 3000
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "QCF_2P",command = "QCB_2P")) || var(52) = 3000
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1020])
trigger2 = movecontact

[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3050
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "QCB_2P",command = "QCF_2P")) || var(52) = 3050
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1020]) || (stateno = 3000 && anim = 3002)
trigger2 = movecontact

[State -1, MEGAMARIO]
type = ChangeState
value = 3100
triggerall = (var(55)<5 && (command = "HCB_2P")) || var(52) = 3100
triggerall = power >= 1000
trigger1 = statetype = A
trigger1 = ctrl || (stateno = 741 && time >= 3)
trigger2 = stateno = 600 || stateno = 610 || stateno = 620 || stateno = 650
trigger2 = movecontact
trigger3 = stateno = 1052
trigger3 = movecontact

[State -1, Critical Heart]
type = ChangeState
value = 3200
triggerall = (var(55)<5 && (command = "CriticalHeart")) || var(52) = 3200
triggerall = power >= 3000
triggerall = numenemy
triggerall = life <= ceil(lifemax*0.3333)
triggerall = statetype != A
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1020])
trigger2 = movecontact

[State -1, FATAL KO]
type = ChangeState
value = 3400
triggerall = (var(55)<5 && (command = "FatalKO")) || var(52) = 3400
triggerall = power >= 3000
triggerall = numenemy
triggerall = p2life <= ceil(enemynear,lifemax*0.3333)
triggerall = statetype != A
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1020])
trigger2 = movecontact

[State -1, SPECIAL POWER]
type = ChangeState
value = 1600
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "QCFx2_Arc",command = "QCBx2_Arc")) || var(52) = 1600
triggerall = power >= 1000
triggerall = !numhelper(2016)
triggerall = !numhelper(2017)
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1020])
trigger2 = movecontact
trigger3 = stateno = 3000
trigger3 = time >= 60
trigger4 = statetype = A
trigger4 = ctrl || stateno = 110 || stateno = 115
trigger5 = stateno = [600,650]
trigger5 = movecontact

[State -1, SPECIAL POWER]
type = ChangeState
value = 1610
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "FHCF_Arc",command = "BHCB_Arc")) || var(52) = 1610
triggerall = power >= 1000
triggerall = !numhelper(1611)
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1020])
trigger2 = movecontact
trigger3 = stateno = 3000
trigger3 = time >= 60

[State -1, Critical Heart Attack]
type = ChangeState
value = 3202
triggerall = (var(55)<5 && (command = "x")) || var(52) = 3202
triggerall = anim != 3208
trigger1 = stateno = 3201
trigger1 = var(0) > 0
trigger1 = time

[State -1, Critical Heart Attack]
type = ChangeState
value = 3203
triggerall = (var(55)<5 && (command = "y")) || var(52) = 3203
triggerall = anim != 3208
trigger1 = stateno = 3201
trigger1 = var(0) > 0
trigger1 = time

[State -1, Critical Heart Attack]
type = ChangeState
value = 3204
triggerall = (var(55)<5 && (command = "z")) || var(52) = 3204
triggerall = anim != 3208
trigger1 = stateno = 3201
trigger1 = var(0) > 0
trigger1 = time

[State -1, Critical Heart Attack]
type = ChangeState
value = 3205
triggerall = (var(55)<5 && (command = "a")) || var(52) = 3205
triggerall = anim != 3208
trigger1 = stateno = 3201
trigger1 = var(0) > 0
trigger1 = time

[State -1, Critical Heart Attack]
type = ChangeState
value = 3206
triggerall = (var(55)<5 && (command = "c")) || var(52) = 3206
triggerall = anim != 3208
trigger1 = stateno = 3201
trigger1 = var(0) > 0
trigger1 = time

;---------------------------------------------------------------------------
[State -1, Straight Ed Boon in a Box]
type = ChangeState
value = 1150
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "HCB_x",command = "HCF_x")) || var(52) = 1150
triggerall = stateno != [1150,1170]
trigger1 = var(9) ;Use combo condition (above)

[State -1, 45' Ed Boon in a Box]
type = ChangeState
value = 1160
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "HCB_y",command = "HCF_y")) || var(52) = 1160
triggerall = stateno != [1150,1170]
trigger1 = var(9) ;Use combo condition (above)

[State -1, 80' Ed Boon in a Box]
type = ChangeState
value = 1170
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "HCB_z",command = "HCF_z")) || var(52) = 1170
triggerall = stateno != [1150,1170]
trigger1 = var(9) ;Use combo condition (above)

[State -1, Fast Prince]
type = ChangeState
value = 1050
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "upper_x",command = "r_upper_x")) || var(52) = 1050
triggerall = stateno != 1050
trigger1 = var(9) ;Use combo condition (above)

[State -1, Slow Prince]
type = ChangeState
value = 1060
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "upper_y",command = "r_upper_y")) || var(52) = 1060
triggerall = stateno != 1060
trigger1 = var(9) ;Use combo condition (above)

[State -1, Multi-Hit Prince]
type = ChangeState
value = 1070
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "upper_z",command = "r_upper_z")) || var(52) = 1070
triggerall = stateno != 1070
trigger1 = var(9) ;Use combo condition (above)

[State -1, Air Prince]
type = ChangeState
value = 1052
triggerall = (var(55)<5 && (command = "upper_x" || command = "upper_y" || command = "upper_z")) || var(52) = 1052
trigger1 = statetype = A
trigger1 = ctrl || (stateno = 741 && time >= 3)
trigger2 = stateno = 600 || stateno = 610 || stateno = 620 || stateno = 650
trigger2 = movecontact

[State -1, Fast Carriage]
type = ChangeState
value = 1000
triggerall = (var(55)<5 && command = "charge_x") || var(52) = 1000
trigger1 = var(9) ;Use combo condition (above)

[State -1, Slow Carriage]
type = ChangeState
value = 1010
triggerall = (var(55)<5 && command = "charge_y") || var(52) = 1010
trigger1 = var(9) ;Use combo condition (above)

[State -1, Armor-Breaking Carriage]
type = ChangeState
value = 1020
triggerall = (var(55)<5 && command = "charge_z") || var(52) = 1020
trigger1 = var(9) ;Use combo condition (above)

[State -1, Drawing]
type = ChangeState
value = 1100
triggerall = (var(55)<5 && command = "imdrawin") || var(52) = 1100
triggerall = stateno != 1100
trigger1 = var(9) ;Use combo condition (above)

[State -1, Let's Roll The Dice]
type = ChangeState
value = 1500
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "QCF_Arc",command = "QCB_Arc")) || var(52) = 1500
triggerall = !numhelper(2010)
trigger1 = var(9) ;Use combo condition (above)
trigger2 = statetype = A
trigger2 = ctrl
trigger3 = stateno = [600,650]
trigger3 = movecontact

[State -1, Let's Roll The Dice]
type = ChangeState
value = 1501
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "QCB_Arc",command = "QCF_Arc")) || var(52) = 1501
triggerall = !numhelper(2010)
trigger1 = var(9) ;Use combo condition (above)
trigger2 = statetype = A
trigger2 = ctrl
trigger3 = stateno = [600,650]
trigger3 = movecontact

;===========================================================================
; Throw
[State -1, EXTENDO]
type = ChangeState
value = 700
triggerall = (var(55)<5 && command = "Extendo") || var(52) = 700
triggerall = fvar(20) = 0
triggerall = statetype != A
triggerall = stateno != [740,749]
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) || (stateno = [1000,1190]) || (stateno = 3000)
trigger2 = movecontact
trigger3 = stateno = [210,212]
trigger3 = animelemtime(5) >= 0
trigger4 = stateno = [1150,1170]
trigger4 = animelemtime(6) >= 0
trigger5 = (stateno = 830 && animelemtime(16) >= 10) || (stateno = 810 && animelemtime(7) > 10) || ((stateno = [1500,1501]) && anim = 1501 && animelemtime(3) > 0)

[State -1, Throw]
type = ChangeState
value = 800
triggerall = (var(55)<5 && ((command = "x" && command = "a") || command = "b")) || var(52) = 800
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Air Throw]
type = ChangeState
value = 850
triggerall = (var(55)<5 && ((command = "x" && command = "a") || command = "b")) || var(52) = 850
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = (command = "FF") || (var(52) = 100)
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = (command = "BB") || (var(52) = 105)
trigger1 = stateno != 105
trigger1 = statetype = S
trigger1 = ctrl

[State -1, Run Fwd]
type = ChangeState
value = 110
triggerall = stateno != 100 || stateno != 105 || stateno != 106
triggerall = !(var(27) & floor(exp(1*ln(2)) + 0.5) )
triggerall = stateno != [110,115]
trigger1 = (command = "AFF") || (var(52) = 100)
trigger1 = statetype = A
trigger1 = pos y <= -15
trigger1 = ctrl

[State -1, Run Bck]
type = ChangeState
value = 115
triggerall = stateno != 100 || stateno != 105 || stateno != 106
triggerall = !(var(27) & floor(exp(1*ln(2)) + 0.5) )
triggerall = stateno != [110,115]
trigger1 = (command = "ABB") || (var(52) = 105)
trigger1 = statetype = A
trigger1 = pos y <= -15
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light]
type = ChangeState
value = 200
triggerall = (var(55)<5 && (command = "x" && command != "holddown")) || var(52) = 200
triggerall = stateno != 200
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 743 && time >= 7) || (stateno = 744 && time >= 16)
trigger2 = stateno = 400
trigger2 = movecontact

[State -1, Stand Medium]
type = ChangeState
value = 211
triggerall = (var(55)<5 && (command = "y" && command = "holdback" && command != "holddown")) || var(52) = 211
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 743 && time >= 7) || (stateno = 744 && time >= 16)
trigger2 = stateno = 200 || stateno = 400
trigger2 = movecontact

[State -1, Stand Medium]
type = ChangeState
value = 212
triggerall = (var(55)<5 && (command = "y" && command = "holdfwd" && command != "holddown")) || var(52) = 212
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 743 && time >= 7) || (stateno = 744 && time >= 16)
trigger2 = stateno = 200 || stateno = 400
trigger2 = movecontact

[State -1, Stand Medium]
type = ChangeState
value = 210
triggerall = (var(55)<5 && (command = "y" && command != "holddown")) || var(52) = 210
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 743 && time >= 7) || (stateno = 744 && time >= 16)
trigger2 = stateno = 200 || stateno = 400
trigger2 = movecontact

[State -1, Stand Hard]
type = ChangeState
value = 220
triggerall = (var(55)<5 && (command = "z" && command != "holddown")) || var(52) = 220
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 743 && time >= 7) || (stateno = 744 && time >= 16)
trigger2 = stateno = 200 || stateno = 400
trigger2 = movecontact

[State -1, Stand CD]
type = ChangeState
value = 250
triggerall = (var(55)<5 && (command = "c" && command != "holddown")) || var(52) = 250
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 743 && time >= 7) || (stateno = 744 && time >= 16)
trigger2 = stateno = 200 || stateno = 400
trigger2 = movecontact

[State -1, Guard Cancel Dash]
type = ChangeState
value = 746
triggerall = fvar(14) >= 60
triggerall = (var(55)<5 && (command = "a" && command = "holdfwd")) || var(52) = 746
triggerall = statetype != A
triggerall = power >= 1000
trigger1 = stateno = [120,159]

[State -1, Guard Cancel Home]
type = ChangeState
value = 747
triggerall = fvar(14) >= 60
triggerall = (var(55)<5 && (command = "a" && command = "holdback")) || var(52) = 747
triggerall = statetype != A
triggerall = power >= 1000
trigger1 = stateno = [120,159]

[State -1, Ground Homing]
type = ChangeState
value = 743
triggerall = fvar(14) >= 60
triggerall = (var(55)<5 && (command = "a" && command = "holdfwd" && command != "holdup" && command != "holddown")) || var(52) = 743
triggerall = statetype != A
triggerall = stateno != [740,749]
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) || (stateno = [1000,1190]) || (stateno = 3000)
trigger2 = movecontact
trigger3 = stateno = [210,212]
trigger3 = animelemtime(5) >= 0
trigger4 = stateno = [1150,1170]
trigger4 = animelemtime(5) >= 8
trigger5 = (stateno = 830 && animelemtime(16) >= 10) || (stateno = 810 && animelemtime(7) > 10) || ((stateno = [1500,1501]) && anim = 1501 && animelemtime(3) > 0)

[State -1, Dash Homing]
type = ChangeState
value = 744
triggerall = fvar(14) >= 60
triggerall = (var(55)<5 && (command = "a" && command = "holdback" && command != "holdup" && command != "holddown")) || var(52) = 744
triggerall = statetype != A
triggerall = stateno != [740,749]
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) || (stateno = [1000,1190]) || (stateno = 3000)
trigger2 = movecontact
trigger3 = stateno = [210,212]
trigger3 = animelemtime(5) >= 0
trigger4 = stateno = [1150,1170]
trigger4 = animelemtime(5) >= 8
trigger5 = (stateno = 830 && animelemtime(16) >= 10) || (stateno = 810 && animelemtime(7) > 10) || ((stateno = [1500,1501]) && anim = 1501 && animelemtime(3) > 0)


[State -1, Stand Homing]
type = ChangeState
value = 740
triggerall = fvar(14) >= 60
triggerall = (var(55)<5 && (command = "a")) || var(52) = 740
triggerall = statetype != A
triggerall = stateno != [740,749]
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) || (stateno = [1000,1190]) || (stateno = 3000)
trigger2 = movecontact
trigger3 = stateno = [210,212]
trigger3 = animelemtime(5) >= 0
trigger4 = stateno = [1150,1170]
trigger4 = animelemtime(6) >= 0
trigger5 = (stateno = 830 && animelemtime(16) >= 10) || (stateno = 810 && animelemtime(7) > 10) || ((stateno = [1500,1501]) && anim = 1501 && animelemtime(3) > 0)

[State -1, Air Homing]
type = ChangeState
value = 742
triggerall = fvar(14) >= 60
triggerall = (var(55)<5 && (command = "a")) || var(52) = 740
triggerall = statetype = A
triggerall = stateno != [740,749]
trigger1 = ctrl
trigger2 = (stateno = [600,699]) || (stateno = [1000,1190]) || (stateno = 3101 && anim = 3102)
trigger2 = movecontact
trigger3 = (stateno = 860 && animelemtime(12) >= 10) || ((stateno = [1500,1501]) && anim = 1501 && animelemtime(3) > 0)

;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = (command = "start") || var(52) = 195 || (var(58) = -2 && winko && !var(48))
triggerall = stateno != 195
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light]
type = ChangeState
value = 400
triggerall = (var(55)<5 && (command = "x" && command = "holddown")) || var(52) = 400
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 743 && time >= 7) || (stateno = 744 && time >= 16)
trigger2 = stateno = 400
trigger2 = movecontact

[State -1, Crouching Medium]
type = ChangeState
value = 410
triggerall = (var(55)<5 && (command = "y" && command = "holddown")) || var(52) = 410
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 743 && time >= 7) || (stateno = 744 && time >= 16)
trigger2 = stateno = 400 || stateno = 200
trigger2 = movecontact

[State -1, Crouching Hard]
type = ChangeState
value = 420
triggerall = (var(55)<5 && (command = "z" && command = "holddown")) || var(52) = 420
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 743 && time >= 7) || (stateno = 744 && time >= 16)
trigger2 = stateno = 400 || stateno = 200
trigger2 = movecontact

[State -1, Crouching CD]
type = ChangeState
value = 450
triggerall = (var(55)<5 && (command = "c" && command = "holddown")) || var(52) = 450
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 743 && time >= 7) || (stateno = 744 && time >= 16)
trigger2 = stateno = 400 || stateno = 200 || stateno = 220
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Light]
type = ChangeState
value = 600
triggerall = (var(55)<5 && command = "x") || var(52) = 600
trigger1 = statetype = A
trigger1 = ctrl || (stateno = 741 && time >= 3)

[State -1, Jump Medium]
type = ChangeState
value = 610
triggerall = (var(55)<5 && command = "y") || var(52) = 610
trigger1 = statetype = A
trigger1 = ctrl || (stateno = 741 && time >= 3)
trigger2 = stateno = 600 || stateno = 650
trigger2 = movecontact

[State -1, Jump Hard]
type = ChangeState
value = 620
triggerall = (var(55)<5 && command = "z") || var(52) = 620
trigger1 = statetype = A
trigger1 = ctrl || (stateno = 741 && time >= 3)
trigger2 = stateno = 600 || stateno = 610 || stateno = 650
trigger2 = movecontact

[State -1, Jump CD]
type = ChangeState
value = 650
triggerall = (var(55)<5 && command = "c") || var(52) = 650
trigger1 = statetype = A
trigger1 = ctrl || (stateno = 741 && time >= 3)
trigger2 = stateno = 600
trigger2 = movecontact

[State -1, Air combo lol]
type = ChangeState
value = 40
triggerall = (command = "holdup") || var(52) = [40,45]
trigger1 = var(55)
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 220 && animelemtime(4)>0) || (stateno = 450)
trigger2 = movehit
trigger3 = stateno = 830 && animelemtime(17)>0
trigger4 = (stateno = 743 && time >= 7) || (stateno = 744 && time >= 16)

[State -1, Air combo lol]
type = ChangeState
value = 45
triggerall = (command = "holdup") || var(52) = [40,45]
triggerall = !(var(27) & floor(exp(0*ln(2)) + 0.5) )
trigger1 = stateno = 600 || stateno = 650
trigger1 = movecontact


